==> mongodb-6.0.22.gh.tar.gz: mongo-r6.0.22/src/mongo/db/update/delta_executor.cpp <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/update/delta_executor.h"

#include "mongo/bson/mutable/document.h"
#include "mongo/db/update/object_replace_executor.h"
#include "mongo/db/update/update_oplog_entry_serialization.h"

namespace mongo {

DeltaExecutor::ApplyResult DeltaExecutor::applyUpdate(
    UpdateExecutor::ApplyParams applyParams) const {
    const auto originalDoc = applyParams.element.getDocument().getObject();

    auto applyDiffOutput = doc_diff::applyDiff(
        originalDoc, _diff, applyParams.indexData, _mustCheckExistenceForInsertOperations);
    const auto& postImage = applyDiffOutput.postImage;
    auto postImageHasId = postImage.hasField("_id");

    auto result = ObjectReplaceExecutor::applyReplacementUpdate(
        std::move(applyParams), postImage, postImageHasId);
    result.indexesAffected = applyDiffOutput.indexesAffected;
    result.oplogEntry = _outputOplogEntry;
    return result;
}
}  // namespace mongo

==> mongodb-7.0.23.gh.tar.gz: mongo-r7.0.23/src/mongo/db/update/delta_executor.cpp <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/update/delta_executor.h"

#include "mongo/bson/mutable/document.h"
#include "mongo/db/update/object_replace_executor.h"
#include "mongo/db/update/update_oplog_entry_serialization.h"

namespace mongo {

DeltaExecutor::ApplyResult DeltaExecutor::applyUpdate(
    UpdateExecutor::ApplyParams applyParams) const {
    const auto originalDoc = applyParams.element.getDocument().getObject();

    auto postImage =
        doc_diff::applyDiff(originalDoc, _diff, _mustCheckExistenceForInsertOperations);
    auto postImageHasId = postImage.hasField("_id");

    auto result = ObjectReplaceExecutor::applyReplacementUpdate(
        std::move(applyParams), postImage, postImageHasId);
    result.oplogEntry = _outputOplogEntry;
    return result;
}
}  // namespace mongo
